@@ -48,6 +48,14 @@ static struct proc_module {
      .rd = NULL,
      .thread = NULL,
      .cleanup = do_Sensors_cleanup},
+    {.name = "GetHardwareInfo",
+     .dim = "GetHardwareInfo",
+     .enabled = CONFIG_BOOLEAN_NO,
+     .update_every = 10 * UPDATE_EVERY_MIN,
+     .func = do_GetHardwareInfo,
+     .rd = NULL,
+     .thread = NULL,
+     .cleanup = do_GetHardwareInfo_cleanup},
     {.name = "PerflibServices",
      .dim = "PerflibServices",
      .enabled = CONFIG_BOOLEAN_YES,
