@@ -60,7 +60,7 @@ func main() {
 		DumpSummary:               opts.DumpSummary,
 	})
 
-	a.Debugf("plugin: name=%s, %s", a.Name, buildinfo.Info())
+	a.Infof("plugin: name=%s, %s", a.Name, buildinfo.Info())
 	if u, err := user.Current(); err == nil {
 		a.Debugf("current user: name=%s, uid=%s", u.Username, u.Uid)
 	}
