@@ -63,10 +63,12 @@ type (
 		vmetricsCollector       *vmetricsCollector
 	}
 	profileState struct {
-		profile        *ddsnmp.Profile
-		initialized    bool
-		globalTags     map[string]string
-		deviceMetadata map[string]ddsnmp.MetaTag
+		profile     *ddsnmp.Profile
+		initialized bool
+		cache       struct {
+			globalTags     map[string]string
+			deviceMetadata map[string]ddsnmp.MetaTag
+		}
 	}
 )
 
@@ -74,7 +76,7 @@ func (c *Collector) CollectDeviceMetadata() (map[string]ddsnmp.MetaTag, error) {
 	meta := make(map[string]ddsnmp.MetaTag)
 
 	for _, prof := range c.profiles {
-		profDeviceMeta, err := c.deviceMetadataCollector.Collect(prof.profile)
+		profDeviceMeta, err := c.deviceMetadataCollector.collect(prof.profile)
 		if err != nil {
 			return nil, err
 		}
@@ -91,7 +93,8 @@ func (c *Collector) Collect() ([]*ddsnmp.ProfileMetrics, error) {
 	var metrics []*ddsnmp.ProfileMetrics
 	var errs []error
 
-	if expired := c.tableCache.clearExpired(); len(expired) > 0 {
+	expired := c.tableCache.clearExpired()
+	if len(expired) > 0 {
 		c.log.Debugf("Cleared %d expired table cache entries", len(expired))
 	}
 
@@ -106,13 +109,16 @@ func (c *Collector) Collect() ([]*ddsnmp.ProfileMetrics, error) {
 
 		metrics = append(metrics, pm)
 
-		if vmetrics := c.vmetricsCollector.Collect(prof.profile.Definition, pm.Metrics); len(vmetrics) > 0 {
+		now := time.Now()
+		if vmetrics := c.vmetricsCollector.collect(prof.profile.Definition, pm.Metrics); len(vmetrics) > 0 {
 			for i := range vmetrics {
 				vmetrics[i].Profile = pm
 			}
 
 			pm.Metrics = slices.DeleteFunc(pm.Metrics, func(m ddsnmp.Metric) bool { return strings.HasPrefix(m.Name, "_") })
 			pm.Metrics = append(pm.Metrics, vmetrics...)
+			pm.Stats.Metrics.Virtual += int64(len(vmetrics))
+			pm.Stats.Timing.VirtualMetrics = time.Since(now)
 		}
 	}
 
@@ -142,42 +148,47 @@ func (c *Collector) SetSNMPClient(snmpClient gosnmp.Handler) {
 }
 
 func (c *Collector) collectProfile(ps *profileState) (*ddsnmp.ProfileMetrics, error) {
+	pm := &ddsnmp.ProfileMetrics{
+		Source: ps.profile.SourceFile,
+	}
+
 	if !ps.initialized {
-		globalTag, err := c.globalTagsCollector.Collect(ps.profile)
+		globalTag, err := c.globalTagsCollector.collect(ps.profile)
 		if err != nil {
 			return nil, fmt.Errorf("failed to collect global tags: %w", err)
 		}
+		ps.cache.globalTags = globalTag
 
-		deviceMeta, err := c.deviceMetadataCollector.Collect(ps.profile)
+		deviceMeta, err := c.deviceMetadataCollector.collect(ps.profile)
 		if err != nil {
 			return nil, fmt.Errorf("failed to collect device metadata: %w", err)
 		}
+		ps.cache.deviceMetadata = deviceMeta
 
-		ps.globalTags = globalTag
-		ps.deviceMetadata = deviceMeta
 		ps.initialized = true
 	}
 
-	var metrics []ddsnmp.Metric
+	pm.Tags = maps.Clone(ps.cache.globalTags)
+	pm.DeviceMetadata = maps.Clone(ps.cache.deviceMetadata)
 
-	scalarMetrics, err := c.scalarCollector.Collect(ps.profile)
+	now := time.Now()
+	scalarMetrics, err := c.scalarCollector.collect(ps.profile, &pm.Stats)
 	if err != nil {
 		return nil, err
 	}
-	metrics = append(metrics, scalarMetrics...)
+	pm.Metrics = append(pm.Metrics, scalarMetrics...)
+	pm.Stats.Timing.Scalar = time.Since(now)
+	pm.Stats.Metrics.Scalar += int64(len(scalarMetrics))
 
-	tableMetrics, err := c.tableCollector.Collect(ps.profile)
+	now = time.Now()
+	tableMetrics, err := c.tableCollector.collect(ps.profile, &pm.Stats)
 	if err != nil {
 		return nil, err
 	}
-	metrics = append(metrics, tableMetrics...)
+	pm.Metrics = append(pm.Metrics, tableMetrics...)
+	pm.Stats.Timing.Table = time.Since(now)
+	pm.Stats.Metrics.Table += int64(len(tableMetrics))
 
-	pm := &ddsnmp.ProfileMetrics{
-		Source:         ps.profile.SourceFile,
-		DeviceMetadata: maps.Clone(ps.deviceMetadata),
-		Tags:           maps.Clone(ps.globalTags),
-		Metrics:        metrics,
-	}
 	for i := range pm.Metrics {
 		pm.Metrics[i].Profile = pm
 	}
