@@ -7,8 +7,8 @@ import (
 	"errors"
 	"fmt"
 
+	"github.com/netdata/netdata/go/plugins/pkg/tlscfg"
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/socket"
-	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/tlscfg"
 )
 
 func (c *Collector) verifyConfig() error {
